/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.twa.tmx.dialogs;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Shell;

import benten.core.XliffFileFilter;
import benten.twa.tmx.handler.ExtractTmxFragmentHandler.ExtractTmxFragmentStatus;
import benten.twa.ui.AbstractWorkflowDialog;
import benten.twa.ui.DirectoryTextField;
import benten.twa.ui.FileTextField;
import benten.ui.UiStatus;
import benten.ui.UiStatusException;

/**
 * TMX フラグメント抽出ダイアログです。
 */
public class ExtractTmxFragmentDialog extends AbstractWorkflowDialog {

	private final ExtractTmxFragmentControls controls = new ExtractTmxFragmentControls();

	public static class ExtractTmxFragmentControls {
		public FileTextField targetFileText;
		public DirectoryTextField toDirText;
		public Button includeDateCheck;
	}

	public ExtractTmxFragmentDialog(Shell parentShell, IStructuredSelection selection) {
		super(parentShell, selection, "TMX フラグメントの抽出");
	}

	@Override
	protected void configureShell(Shell newShell) {
		super.configureShell(newShell);
		newShell.setText("TMX フラグメントの抽出");
	}

	@Override
	protected Point getInitialSize() {
		return new Point(400, 200);
	}

	@Override
	public void createControls(Composite composite) {
		composite.setLayout(new GridLayout(3, false));

		controls.targetFileText = new FileTextField(composite, "XLIFF", XliffFileFilter.DEFAULT_EXTENSION);

		controls.targetFileText.addModifyListener(this);
		controls.targetFileText.setText(getStructuredSelectionString());

		controls.toDirText = new DirectoryTextField(composite, "TMX");
		controls.toDirText.addModifyListener(this);

		Group group1 = new Group(composite, SWT.NULL);
		group1.setText("出力ファイル名オプション");
		GridData outputFileNameOptionGrid = new GridData(GridData.FILL_HORIZONTAL);
		outputFileNameOptionGrid.horizontalSpan = 2;
		group1.setLayoutData(outputFileNameOptionGrid);
		group1.setLayout(new GridLayout(1, false));

		controls.includeDateCheck = new Button(group1, SWT.CHECK);
		controls.includeDateCheck.setText("ファイル名に年月日を含める");
		controls.includeDateCheck.setSelection(true);

		copyParent(controls.targetFileText, controls.toDirText);
	}

	@Override
	public IStatus getResultStatus() {
		ExtractTmxFragmentStatus status = new ExtractTmxFragmentStatus();
		status.targetFile = controls.targetFileText.getFile();
		status.toDir = controls.toDirText.getFile();
		status.includeDate = controls.includeDateCheck.getSelection();
		return status;
	}

	@Override
	public IStatus validate() throws UiStatusException {
		validatePath(controls.targetFileText);
		validatePath(controls.toDirText);
		return UiStatus.OK_STATUS;
	}
}
