/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.twa.tmx.dialogs;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Shell;

import benten.core.TmxFileFilter;
import benten.twa.tmx.handler.MergeTmxHandler.MergeTmxStatus;
import benten.twa.ui.AbstractWorkflowDialog;
import benten.twa.ui.FileTextField;
import benten.ui.UiStatus;
import benten.ui.UiStatusException;

public class MergeTmxDialog extends AbstractWorkflowDialog {

	private final MergeTmxControls controls = new MergeTmxControls();

	public static class MergeTmxControls {
		public FileTextField targetFileText;
		public FileTextField toFileText;
	}

	public MergeTmxDialog(Shell parentShell, IStructuredSelection selection) {
		super(parentShell, selection, "TMX フラグメントのマージ");
	}

	@Override
	protected void configureShell(Shell newShell) {
		super.configureShell(newShell);
		newShell.setText("TMX フラグメントのマージ");
	}

	@Override
	protected Point getInitialSize() {
		return new Point(400, 200);
	}

	@Override
	public void createControls(Composite composite) {
		composite.setLayout(new GridLayout(3, false));

		controls.targetFileText = new FileTextField(composite, "マージ元", TmxFileFilter.DEFAULT_EXTENSION);
		controls.targetFileText.addModifyListener(this);
		controls.targetFileText.setText(getStructuredSelectionString());

		controls.toFileText = new FileTextField(composite, "マージ先");
		controls.toFileText.addModifyListener(this);

		// copyParent(controls.targetFileText, controls.toFileText);
	}

	@Override
	public IStatus getResultStatus() {
		MergeTmxStatus status = new MergeTmxStatus();
		status.targetFile = controls.targetFileText.getFile();
		status.toFile = controls.toFileText.getFile();
		return status;
	}

	@Override
	public IStatus validate() throws UiStatusException {
		validatePath(controls.targetFileText);
		validatePath(controls.toFileText);
		return UiStatus.OK_STATUS;
	}
}
